@@ -3,12 +3,11 @@ function(SHAPEFILE="f09uqresids64", CODE="f09_R64_") {
 
   #==================================================
   #
-  #  FILENAME:   ShrinkShape.r
   #  NAME:       shpsplitter()
   #  AUTHOR:     Tarmo K. Remmel
-  #  DATE:       29 February 2016
+  #  DATE:       25 October 2016
   #  NOTES:      Split shapefile into multiple shapefiles, one shape in each file
-  # 			 This is necessary for ssr2() to run
+  # 		 This is necessary for ssr2() to run
   #  NEEDS:      A shapefile (polygons), properly built
   #              libraries: sp, rgdal
   #
@@ -20,11 +19,6 @@ function(SHAPEFILE="f09uqresids64", CODE="f09_R64_") {
   #              of a multi-part shapefile
   #    
   #==================================================
-
-  # LOAD REQUIRED LIBRARIES
-  #library(sp)
-  #library(rgdal)
-
   
   filename <- paste("./", SHAPEFILE, ".shp", sep="")
   data <- readOGR(filename, SHAPEFILE)
@@ -35,4 +29,4 @@ function(SHAPEFILE="f09uqresids64", CODE="f09_R64_") {
     writeOGR(tmp, dsn=getwd(), paste(CODE, unique[i], sep=""), driver="ESRI Shapefile", check_exists=TRUE, overwrite_layer=TRUE)
   } # END FOR: i
 
-}
+} # END FUNCTION: shpsplitter
